@@ -3,6 +3,7 @@ from trexlib import conf
 import logging
 from basicauth import encode as basic_encode, decode as basic_decode
 
+logger = logging.getLogger('debug')
 
 #-----------------------------------------------------------------
 # Password Hashing & Blending
@@ -70,6 +71,10 @@ def create_basic_authentication(username, password):
 
 def verfiy_basic_authentication(authentication_token, username, password):
     (decoded_username, decoded_password)  = basic_decode(authentication_token)
+    
+    logger.debug('decoded_username')
+    logger.debug('decoded_password')
+    
     return decoded_username==username and decoded_password==password
 
 
@@ -89,4 +94,5 @@ def __int2ascii(value):
             ascii_keys+=chr(a)
 
         return ascii_keys
+    
 
